//
//  OfferwallScreen.cpp
//  sample
//
//  Created by Pankaj Kumar on 22/04/15.
//
//

#include "OfferwallScreen.h"
#include "IwGx.h"
#include "input.h"
#include "UIComponents.h"
#include "resources.h"
#include "PokktNativeManager.h"
#include <sstream>
#include "Storage.h"

PokktMarmaladeConfig *OfferwallScreen::pokktConfig = new PokktMarmaladeConfig();

OfferwallScreen::OfferwallScreen()
{
    // listen for pokkt events
    PokktNativeManager::setListener(PokktNativeManager::CoinResponseEvent, pokkt_event_selector(OfferwallScreen::handleCoinResponse), this);
    PokktNativeManager::setListener(PokktNativeManager::CoinResponseWithTransIdEvent, pokkt_event_selector(OfferwallScreen::handleCoinResponseWithTrId), this);
    PokktNativeManager::setListener(PokktNativeManager::CoinResponseFailedEvent, pokkt_event_selector(OfferwallScreen::handleCoinResponseFailed), this);
    PokktNativeManager::setListener(PokktNativeManager::CampaignAvailabilityEvent, pokkt_event_selector(OfferwallScreen::handleCampaignAvailibity), this);
    PokktNativeManager::setListener(PokktNativeManager::OfferwallClosedEvent, pokkt_event_selector(OfferwallScreen::handleOfferwallclosed), this);
}

OfferwallScreen::~OfferwallScreen()
{
    PokktNativeManager::removeListener(PokktNativeManager::CoinResponseEvent);
    PokktNativeManager::removeListener(PokktNativeManager::CoinResponseWithTransIdEvent);
    PokktNativeManager::removeListener(PokktNativeManager::CoinResponseFailedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::CampaignAvailabilityEvent);
    PokktNativeManager::removeListener(PokktNativeManager::OfferwallClosedEvent);
}

void OfferwallScreen::Update(float deltaTime, float alphaMul)
{
    if(!m_IsActive)
        return;
    
    Scene:Scene::Update(deltaTime, alphaMul);
    
    //Detect screen tap
    if(m_IsInputActive && m_Manager->GetCurrent() == this && !g_pInput->m_Touched && g_pInput->m_PrevTouched)
    {
        g_pInput->Reset();
        
        if(getOfferwallBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            pokktConfig->setOfferWallAssetValue("");
            PokktNativeManager::getCoins(pokktConfig);
        }
        else if(getOfferwallWithFixedValueBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            pokktConfig->setOfferWallAssetValue("400");
            PokktNativeManager::getCoins(pokktConfig);
        }
        else if(incompleteCallBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            PokktNativeManager::getPendingCoins();
        }
    }
}

void OfferwallScreen::Render()
{
    Scene::Render();
}

void OfferwallScreen::Init()
{
    Scene::Init();
    
    // Create UI
    CSprite* background = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() / 2, g_pResources->getScreenBG(), 0.5f, 0.5f);
    // Fit background to screen size
    background->m_ScaleX = (float)IwGxGetScreenWidth() / background->GetImage()->GetWidth();
    background->m_ScaleY = (float)IwGxGetScreenHeight() / background->GetImage()->GetHeight();
    AddChild(background);
    
    CSprite* logo = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() * 0.25f, g_pResources->getLogo(), 0.5f, 0.5f);
    AddChild(logo);

    pointsEarnedLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() * 0.45f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_LEFT, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Points earned: 0");
    AddChild(pointsEarnedLbl);
    
    //button 1
    float y_pos = (float)IwGxGetScreenHeight() * 0.51f;
    getOfferwallBtn = UIComponents::getSprite(IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(getOfferwallBtn);

    y_pos = (float)IwGxGetScreenHeight() * 0.525f;
    CLabel* getOfferwallLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Get Offerwall (Any asset value)");
    AddChild(getOfferwallLbl);

    //button 2
    y_pos = (float)IwGxGetScreenHeight() * 0.66f;
    getOfferwallWithFixedValueBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
    AddChild(getOfferwallWithFixedValueBtn);

    y_pos = (float)IwGxGetScreenHeight() * 0.675f;
    CLabel* getOfferwallWithFixedValueLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Get Offerwall ( Fix assets value 100 )");
    AddChild(getOfferwallWithFixedValueLbl);

    //button3
    y_pos = (float)IwGxGetScreenHeight() * 0.74f;
    incompleteCallBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(incompleteCallBtn);

    y_pos = (float)IwGxGetScreenHeight() * 0.755f;
    CLabel* incompleteCallLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Incomplete callback");
    AddChild(incompleteCallLbl);
    
    pointsEarnedLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, (float)IwGxGetScreenHeight() * 0.45f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Points earned: 0");
    AddChild(pointsEarnedLbl);
}

void OfferwallScreen::handleCoinResponse(std::string coins)
{
    POKKTLOG("[POKKT-CPP] Coins earned from offerwall: %s", coins.c_str());
    
    int coinsInt = 0;
    std::stringstream(coins) >> coinsInt;
    _coinsEarned += coinsInt;
    
    char buf[100];
    sprintf(buf, "%d", _coinsEarned);
    pointsEarnedLbl->SetText(buf);
}

void OfferwallScreen::handleCoinResponseWithTrId(std::string coinsWithTrId)
{
    // extract comma separated values
    std::stringstream stream(coinsWithTrId);
    std::string value;
    std::vector<std::string> values;
    while (getline(stream, value, ','))
    {
        values.push_back(value);
        if (stream.peek() == ',')
            stream.ignore();
    }
    
    if (values.size() < 2)
        return; // the values received are not proper
    
    std::string points = values[0];
    std::string transId = values[1];
    
    if (points == "-1")
    {
        // no points earned
    }
    else
    {
        // points earned equal to coins with transaction id
    }
    
    if (values.size() >= 2)
        POKKTLOG("[POKKT-CPP] Coins earned with trId: %s, coins: %s.", values[1].c_str(), values[0].c_str());
    else
        POKKTLOG("[POKKT-CPP] Error receiving coins with transaction id!");
    
    pointsEarnedLbl->SetText(coinsWithTrId.c_str());
}

void OfferwallScreen::handleCoinResponseFailed(std::string message)
{
    // pending coins request fails
    POKKTLOG("[POKKT-CPP] Failed to get Pending coins!");
}

void OfferwallScreen::handleCampaignAvailibity(std::string message)
{
    bool available = message == "true";
    
    POKKTLOG("[POKKT-CPP] Offerwall Campaign availability: %s", (available ? "available" : "no campaigns"));
}

void OfferwallScreen::handleOfferwallclosed(std::string message)
{
    POKKTLOG("[POKKT-CPP] Offerwall Closed!");
    PokktNativeManager::getPendingCoins();
}

void OfferwallScreen::initPokkt()
{
    // SET THESE UP AS PER VALUES PROVIDED TO YOU
    
    pokktConfig->setSecurityKey("iJ02lJss0M");
    pokktConfig->setApplicationId("a2717a45b835b5e9f50284a38d62a74e");
    pokktConfig->setIntegrationType(PokktMarmaladeConfig::INTEGRATION_TYPE_ALL);
    
    // set auto caching
    pokktConfig->setAutoCacheVideo(false);//Storage::getAutoCaching(): seeting fallse because there is no need to download video if suer clickes on offerwall
    
    // set params to init pokkt
    PokktNativeManager::initPokkt(pokktConfig);
}
